@@ -5,7 +5,7 @@ use std::sync::{Arc, Mutex};
 use super::{
     utils::CHANNEL_PAIR_DELIMITER,
     ws_client_internal::{MiscMessage, WSClientInternal},
-    Candlestick, OrderBook, OrderBookSnapshot, Ticker, Trade, BBO,
+    Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
 };
 
 use log::*;
@@ -95,8 +95,8 @@ impl<'a> BBO for BithumbWSClient<'a> {
     }
 }
 
-impl<'a> OrderBookSnapshot for BithumbWSClient<'a> {
-    fn subscribe_orderbook_snapshot(&self, _pairs: &[String]) {
+impl<'a> OrderBookTopK for BithumbWSClient<'a> {
+    fn subscribe_orderbook_topk(&self, _pairs: &[String]) {
         panic!("CoinbasePro does NOT have orderbook snapshot channel");
     }
 }
