@@ -148,7 +148,6 @@ impl<'a> WSClientInternal<'a> {
     // Handle a text msg from Message::Text or Message::Binary
     // Returns true if gets a normal message, otherwise false
     fn handle_msg(&self, txt: &str) -> bool {
-        println!("{}", txt);
         match (self.on_misc_msg)(txt) {
             MiscMessage::Misc => false,
             MiscMessage::Pong => {
@@ -400,8 +399,8 @@ macro_rules! define_client {
                 <$struct_name as OrderBook>::subscribe_orderbook(self, channels);
             }
 
-            fn subscribe_orderbook_snapshot(&self, channels: &[String]) {
-                <$struct_name as OrderBookSnapshot>::subscribe_orderbook_snapshot(self, channels);
+            fn subscribe_orderbook_topk(&self, channels: &[String]) {
+                <$struct_name as OrderBookTopK>::subscribe_orderbook_topk(self, channels);
             }
 
             fn subscribe_ticker(&self, channels: &[String]) {
