@@ -36,7 +36,7 @@ mod deribit_inverse_future {
         gen_test_code!(
             DeribitWSClient,
             subscribe_trade,
-            &vec!["BTC-31DEC21".to_string(), "BTC-31DEC21".to_string()]
+            &vec!["BTC-26NOV21".to_string(), "BTC-31DEC21".to_string()]
         );
     }
 
@@ -59,10 +59,10 @@ mod deribit_inverse_future {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC-31DEC21".to_string()]
         );
     }
@@ -116,10 +116,10 @@ mod deribit_inverse_swap {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC-PERPETUAL".to_string()]
         );
     }
@@ -178,6 +178,7 @@ mod deribit_option {
     }
 
     #[test]
+    #[ignore]
     fn subscribe_orderbook() {
         gen_test_code!(
             DeribitWSClient,
@@ -190,10 +191,11 @@ mod deribit_option {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    #[ignore]
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &SYMBOLS
                 .iter()
                 .map(|s| s.to_string())
