@@ -67,10 +67,10 @@ mod huobi_spot {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             HuobiSpotWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["btcusdt".to_string()]
         );
     }
@@ -80,18 +80,6 @@ mod huobi_spot {
         gen_test_subscribe_candlestick!(HuobiSpotWSClient, &vec!["btcusdt".to_string()], 60);
         gen_test_subscribe_candlestick!(HuobiSpotWSClient, &vec!["btcusdt".to_string()], 2592000);
     }
-
-    #[test]
-    fn huobi_hb10() {
-        gen_test_code!(
-            HuobiSpotWSClient,
-            subscribe,
-            &vec![
-                "market.hb10usdt.trade.detail".to_string(),
-                "market.huobi10.kline.1min".to_string()
-            ]
-        );
-    }
 }
 
 #[cfg(test)]
@@ -145,10 +133,10 @@ mod huobi_inverse_future {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             HuobiFutureWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC_CQ".to_string()]
         );
     }
@@ -211,10 +199,10 @@ mod huobi_linear_swap {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             HuobiLinearSwapWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC-USDT".to_string()]
         );
     }
@@ -317,10 +305,10 @@ mod huobi_inverse_swap {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             HuobiInverseSwapWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC-USD".to_string()]
         );
     }
@@ -407,6 +395,7 @@ mod huobi_option {
     }
 
     #[test]
+    #[ignore]
     fn subscribe_ticker() {
         gen_test_code!(
             HuobiOptionWSClient,
@@ -426,6 +415,7 @@ mod huobi_option {
     }
 
     #[test]
+    #[ignore]
     fn subscribe_orderbook() {
         gen_test_code!(
             HuobiOptionWSClient,
@@ -435,15 +425,17 @@ mod huobi_option {
     }
 
     #[test]
-    fn subscribe_orderbook_snapshot() {
+    #[ignore]
+    fn subscribe_orderbook_topk() {
         gen_test_code!(
             HuobiOptionWSClient,
-            subscribe_orderbook_snapshot,
+            subscribe_orderbook_topk,
             &vec!["BTC-USDT-210625-P-27000".to_string()]
         );
     }
 
     #[test]
+    #[ignore]
     fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(
             HuobiOptionWSClient,
@@ -458,6 +450,7 @@ mod huobi_option {
     }
 
     #[test]
+    #[ignore]
     fn subscribe_overview() {
         gen_test_code!(
             HuobiOptionWSClient,
